#ifndef LOGSUMEXP_H
#define LOGSUMEXP_H

#include "config.h"

double logSumExp(const arma::vec& x);

#endif
